<?php
/**
 * Helper
 *
 * Part of the integration
 *
 * @package  Okiano
 */

namespace Okiano;

defined( 'ABSPATH' ) || exit;

/**
 * Helper
 */
class Helper {
	/**
	 * Option_key
	 *
	 * @var string
	 */
	private static $option_key = null;

	/**
	 * Wc_log
	 *
	 * @param  mixed $level a required parameter.
	 * @param  mixed $message a required parameter.
	 * @param  mixed $force a required parameter.
	 * @return void
	 */
	public static function wc_log( $level, $message, $force = false ) {
		if ( ( WP_DEBUG || $force )
			&& function_exists( 'wc_get_logger' )
			&& $message
			&& in_array( $level, array( 'debug', 'info', 'notice', 'warning', 'error', 'critical', 'alert', 'emergency' ), true ) ) {
			wc_get_logger()->log( $level, $message, array( 'source' => 'okiano-marketing' ) );
		}
	}

	/**
	 * Get_option_key
	 *
	 * @return mixed
	 */
	public static function get_option_key() {
		if ( null === self::$option_key ) {
			if ( function_exists( 'wc' ) && class_exists( 'WC_Integration' ) ) {
				self::$option_key = ( new WC_Integration( false ) )->get_option_key();
			} else {
				self::$option_key = 'woocommerce_okn_wcintegration_settings';
			}
		}

		return self::$option_key;
	}

	/**
	 * Get_plugin_options
	 *
	 * @return mixed
	 */
	public static function get_plugin_options() {
		return get_option( self::get_option_key(), array() );
	}

	/**
	 * Is_plugin_page
	 *
	 * @param  mixed $page_slug a required parameter.
	 * @return mixed
	 */
	public static function is_plugin_page( $page_slug = null ) {
		global $pagenow;

		if ( 'admin.php' !== $pagenow ) {
			return false;
		}

		if ( null !== $page_slug ) {
			return ( isset( $_GET['page'] ) && $page_slug === $_GET['page'] );
		} else {
			return (
				isset( $_GET['page'] ) && 'wc-settings' === $_GET['page']
				&& isset( $_GET['tab'] ) && 'integration' === $_GET['tab']
				&& isset( $_GET['section'] ) && OKN_WC_INTEGRATION_PAGE_ID === $_GET['section']
			);
		}
	}

	/**
	 * Get_plugin_page
	 *
	 * @return mixed
	 */
	public static function get_plugin_page() {
		return 'admin.php?page=wc-settings&tab=integration&section=' . OKN_WC_INTEGRATION_PAGE_ID;
	}

	/**
	 * Get_wl_supported_languages
	 *
	 * @return mixed
	 */
	public static function get_wl_supported_languages() {
		return array(
			'en_US' => 'en',
		);
	}

	/**
	 * Get_wl_locale
	 *
	 * @return mixed
	 */
	public static function get_wl_locale() {
		if ( function_exists( 'get_user_locale' ) ) {
			$wp_locale = get_user_locale();
		} else {
			$wp_locale = get_locale();
		}

		$supported_langs = self::get_wl_supported_languages();

		if ( array_key_exists( $wp_locale, $supported_langs ) ) {
			return $supported_langs[ $wp_locale ];
		}

		return 'en';
	}

	/**
	 * Get_locale_postfix
	 *
	 * @param  mixed $postfix a required parameter.
	 * @return mixed
	 */
	public static function get_locale_postfix( $postfix = '-' ) {
		if ( function_exists( 'get_user_locale' ) ) {
			$wp_locale = get_user_locale();
		} else {
			$wp_locale = get_locale();
		}

		$supported_langs = self::get_wl_supported_languages();

		if ( array_key_exists( $wp_locale, $supported_langs ) ) {
			if ( 'en_US' === $wp_locale ) {
				return '';
			} else {
				return $postfix . $wp_locale;
			}
		}

		return '';
	}

	/**
	 * Build_signup_url
	 *
	 * @return mixed
	 */
	public static function build_signup_url() {
		$current_user = wp_get_current_user();
		return OKN_WC_WOOOKIANO_BASE_URL . 'woocommerce/redirect?mail=' .
		rawurlencode( $current_user->user_email ) . '&store_url=' . get_site_url();
	}

	/**
	 * Build_continue_url
	 *
	 * @return mixed
	 */
	public static function build_continue_url() {
		$current_user = wp_get_current_user();
		return OKN_WC_WOOOKIANO_BASE_URL . 'woocommerce/redirect?mail=' .
		rawurlencode( $current_user->user_email );
	}

	/**
	 * Clear_options
	 *
	 * @return void
	 */
	public static function clear_options() {
		update_option(
			self::get_option_key(),
			null
		);
	}

	/**
	 * Save_account_info
	 *
	 * @param  mixed $account_id a required parameter.
	 * @return mixed
	 */
	public static function save_account_info( $account_id ) {
		$options = get_option( self::get_option_key() );

		update_option(
			self::get_option_key(),
			array(
				'account_id'        => $account_id,
				'finish_onboarding' => $options['finish_onboarding'],
			)
		);

		return OKN_WC_WOOOKIANO_BASE_URL . 'store-details';
	}

	/**
	 * Save_finish_onboarding
	 *
	 * @return mixed
	 */
	public static function save_finish_onboarding() {
		$options = get_option( self::get_option_key() );

		update_option(
			self::get_option_key(),
			array(
				'account_id'        => $options['account_id'],
				'finish_onboarding' => true,
			)
		);

		return OKN_WC_WOOOKIANO_BASE_URL . 'dashboard';
	}

	/**
	 * Check_redirect_for_wc_auth
	 *
	 * @return void
	 */
	public static function check_redirect_for_wc_auth() {
		if ( is_network_admin() ) {
			return;
		}

		if ( ! function_exists( 'wc' ) ) {
			return;
		}

		$authorization_url = get_site_transient( OKN_WC_TRANSIENT_AUTH_REDIRECT );

		if ( ! empty( $authorization_url ) ) {
			delete_site_transient( OKN_WC_TRANSIENT_AUTH_REDIRECT );

			if ( wp_safe_redirect( $authorization_url ) ) {
				exit;
			}
		}
	}

	/**
	 * Get_onboarding_message
	 *
	 * @return mixed
	 */
	public static function get_onboarding_message() {
		return 'Okiano Marketing plugin for WooCommerce is successfully Installed and Activated. You still need to sign-up to Okiano Service and authorize access to your product catalog. Please follow this link ' . esc_url( self::get_plugin_page() ) . ' to complete your Onboarding now.';
	}

	/**
	 * Get_image_link
	 *
	 * @param  mixed $image_base_name a required parameter.
	 * @param  mixed $image_extension a required parameter.
	 * @return mixed
	 */
	public static function get_image_link( $image_base_name, $image_extension ) {
		return OKN_WC_PLUGIN_URL . $image_base_name . self::get_locale_postfix() . $image_extension;
	}
}
