<?php
/**
 * Integration
 *
 * Part of the integration
 *
 * @package  Okiano
 */

namespace Okiano;

defined( 'ABSPATH' ) || exit;

/**
 * WC_Integration
 */
class WC_Integration extends \WC_Integration {

	/**
	 * __construct
	 *
	 * @param  mixed $init a required parameter.
	 * @return void
	 */
	public function __construct( $init = true ) {
		global $woocommerce;

		$this->id           = OKN_WC_INTEGRATION_PAGE_ID;
		$this->method_title = __( 'Okiano Marketing for WooCommerce', 'okiano-marketing' );  // This is for the sub-section text.

		if ( true === $init ) {
			$this->init_form_fields();
			$this->init_settings();

			$this->account_id = $this->get_option( 'account_id' );

			add_action( 'woocommerce_update_options_integration_' . $this->id, array( $this, 'process_admin_options' ) );
		}
	}

	/**
	 * Init_form_fields
	 *
	 * @return void
	 */
	public function init_form_fields() {
		$this->form_fields = array(
			'account_id' => array(
				'title'   => __( 'Account Id', 'okiano-marketing' ),
				'type'    => 'text',
				'default' => '',
			),
		);
	}

	/**
	 * Admin_options
	 *
	 * @return void
	 */
	public function admin_options() {
		Helper::check_redirect_for_wc_auth();

		$GLOBALS['hide_save_button'] = true;

		if ( ! empty( $this->settings['account_id'] ) &&
			array_key_exists( 'finish_onboarding', $this->settings ) &&
			true === $this->settings['finish_onboarding'] ) {

			include_once OKN_WC_PLUGIN_DIR . 'dashboard.php';

		} elseif ( ! empty( $this->settings['account_id'] ) ) {
			include_once OKN_WC_PLUGIN_DIR . 'onboarding.php';

		} else {
			include_once OKN_WC_PLUGIN_DIR . 'getstarted.php';
		}
	}

	/**
	 * Generate_desc_html
	 *
	 * @param  mixed $key a required parameter.
	 * @param  mixed $data a required parameter.
	 * @return mixed
	 */
	public function generate_desc_html( $key, $data ) {
		ob_start();
		?>
		<tr valign="top">
			<th scope="row" class="titledesc" style="padding: 0;">
			</th>
			<td class="forminp" style="padding: 0 0 0 10px;">
				<fieldset>
					<?php echo $this->get_description_html( $data ); ?>
				</fieldset>
			</td>
		</tr>
		<?php
		return ob_get_clean();
	}

}
